@@ -28,6 +28,7 @@ from typing import List
 from typing import Tuple
 from typing import Dict
 from typing import Callable
+from enum import Enum, Flag
 import sys
 import os
 import logging
@@ -335,6 +336,317 @@ def dict_update_existing_keys(
         if key in pdict:
             pdict[key] = other_pdict[key]
 
+class Capabilite(Flag):
+    '''Compatibility class to handle IBus.Capabilite the same way no matter
+    what version of ibus is used.
+
+    For example, older versions of ibus might not have IBus.Capabilite.SYNC_PROCESS_KEY
+    (or maybe even do not have IBus.Capabilite at all). Then
+
+        capabilities & IBus.Capabilite.SYNC_PROCESS_KEY
+
+    will produce an exception. But when using this compatibility class
+
+        capabilities & IBus.Capabilite.SYNC_PROCESS_KEY
+
+    will just be False but not cause an exception.
+
+    >>> int(Capabilite.PREEDIT_TEXT)
+    1
+
+    >>> Capabilite.PREEDIT_TEXT == 1
+    True
+
+    >>> Capabilite.PREEDIT_TEXT | 2
+    3
+
+    >>> 2 | Capabilite.PREEDIT_TEXT
+    3
+
+    >>> int(Capabilite.PREEDIT_TEXT | Capabilite.AUXILIARY_TEXT)
+    3
+
+    >>> 3 == Capabilite.AUXILIARY_TEXT | Capabilite.PREEDIT_TEXT
+    True
+
+    >>> 3 == Capabilite.AUXILIARY_TEXT | IBus.Capabilite.PREEDIT_TEXT
+    True
+
+    >>> Capabilite.PREEDIT_TEXT == IBus.Capabilite.PREEDIT_TEXT
+    True
+    '''
+    def __new__(cls, attr: str) -> Any:
+        obj = object.__new__(cls)
+        if hasattr(IBus, 'Capabilite') and hasattr(IBus.Capabilite, attr):
+            obj._value_ = int(getattr(IBus.Capabilite, attr))
+        else:
+            obj._value_ = 0
+        return obj
+
+    def __int__(self) -> int:
+        return int(self._value_)
+
+    def __eq__(self, other: Any) -> bool:
+        if (self.__class__ is other.__class__
+            or other.__class__ is IBus.Capabilite):
+            return bool(int(self) == int(other))
+        if other.__class__ is int or other.__class__ is float:
+            return bool(int(self) == other)
+        return NotImplemented
+
+    def __or__(self, other: Any) -> Any:
+        if self.__class__ is other.__class__:
+            return self.value | other.value
+        if (other.__class__ is IBus.Capabilite):
+            return int(self) | int(other)
+        if other.__class__ is int:
+            return int(self) | other
+        return NotImplemented
+
+    def __ror__(self, other: Any) -> Any:
+        return self.__or__(other)
+
+    def __and__(self, other: Any) -> Any:
+        if self.__class__ is other.__class__:
+            return self.value & other.value
+        if (other.__class__ is IBus.Capabilite):
+            return int(self) & int(other)
+        if other.__class__ is int:
+            return int(self) & other
+        return NotImplemented
+
+    def __rand__(self, other: Any) -> Any:
+        return self.__and__(other)
+
+    PREEDIT_TEXT = ('PREEDIT_TEXT')
+    AUXILIARY_TEXT = ('AUXILIARY_TEXT')
+    LOOKUP_TABLE = ('LOOKUP_TABLE')
+    FOCUS = ('FOCUS')
+    PROPERTY = ('PROPERTY')
+    SURROUNDING_TEXT = ('SURROUNDING_TEXT')
+    OSK = ('OSK')
+    SYNC_PROCESS_KEY = ('SYNC_PROCESS_KEY')
+
+class InputPurpose(Enum):
+    '''Compatibility class to handle InputPurpose the same way no matter
+    what version of ibus is used.
+
+    For example, older versions of ibus might not have
+    IBus.InputPurpose.TERMINAL and then
+
+        input_purpose == IBus.InputPurpose.TERMINAL
+
+    will produce an exception. But when using this compatibility class
+
+        input_purpose == InputPurpose.TERMINAL
+
+    will just be False but not cause an exception.
+
+    See also:
+
+    https://docs.gtk.org/gtk3/enum.InputPurpose.html
+    https://docs.gtk.org/gtk4/enum.InputPurpose.html
+
+    Examples:
+
+    >>> int(InputPurpose.PASSWORD)
+    8
+
+    >>> 8 == InputPurpose.PASSWORD
+    True
+
+    >>> int(InputPurpose.PIN)
+    9
+
+    >>> InputPurpose.PASSWORD <= InputPurpose.PIN
+    True
+
+    >>> InputPurpose.PASSWORD == Gtk.InputPurpose.PASSWORD
+    True
+
+    >>> InputPurpose.PASSWORD == IBus.InputPurpose.PASSWORD
+    True
+    '''
+    def __new__(cls, attr: str) -> Any:
+        obj = object.__new__(cls)
+        if hasattr(Gtk, 'InputPurpose') and hasattr(Gtk.InputPurpose, attr):
+            obj._value_ = int(getattr(Gtk.InputPurpose, attr))
+        else:
+            obj._value_ = -1
+        return obj
+
+    def __int__(self) -> int:
+        return int(self._value_)
+
+    def __eq__(self, other: Any) -> bool:
+        if (self.__class__ is other.__class__
+            or other.__class__ is Gtk.InputPurpose
+            or other.__class__ is IBus.InputPurpose):
+            return int(self) == int(other)
+        if other.__class__ is int or other.__class__ is float:
+            return bool(int(self) == other)
+        return NotImplemented
+
+    def __gt__(self, other: Any) -> bool:
+        if (self.__class__ is other.__class__
+            or other.__class__ is Gtk.InputPurpose
+            or other.__class__ is IBus.InputPurpose):
+            return int(self) > int(other)
+        if other.__class__ is int or other.__class__ is float:
+            return bool(int(self) > other)
+        return NotImplemented
+
+    def __lt__(self, other: Any) -> bool:
+        if (self.__class__ is other.__class__
+            or other.__class__ is Gtk.InputPurpose
+            or other.__class__ is IBus.InputPurpose):
+            return bool(int(self) < int(other))
+        if other.__class__ is int or other.__class__ is float:
+            return bool(int(self) < other)
+        return NotImplemented
+
+    def __ge__(self, other: Any) -> bool:
+        if (self.__class__ is other.__class__
+            or other.__class__ is Gtk.InputPurpose
+            or other.__class__ is IBus.InputPurpose):
+            return bool(int(self) >= int(other))
+        if other.__class__ is int or other.__class__ is float:
+            return bool(int(self) >= other)
+        return NotImplemented
+
+    def __le__(self, other: Any) -> bool:
+        if (self.__class__ is other.__class__
+            or other.__class__ is Gtk.InputPurpose
+            or other.__class__ is IBus.InputPurpose):
+            return bool(int(self) <= int(other))
+        if other.__class__ is int or other.__class__ is float:
+            return bool(int(self) <= other)
+        return NotImplemented
+
+    FREE_FORM = ('FREE_FORM')
+    ALPHA = ('ALPHA')
+    DIGITS = ('DIGITS')
+    NUMBER = ('NUMBER')
+    PHONE = ('PHONE')
+    URL = ('URL')
+    EMAIL = ('EMAIL')
+    NAME = ('NAME')
+    PASSWORD = ('PASSWORD')
+    PIN = ('PIN')
+    TERMINAL = ('TERMINAL')
+
+class InputHints(Flag):
+    '''Compatibility class to handle InputHints the same way no matter
+    what version of ibus is used.
+
+    For example, older versions of ibus might not have IBus.InputHints.PRIVATE
+    (or maybe even do not have IBus.InputHints at all). Then
+
+        input_hints & IBus.InputHints.PRIVATE
+
+    will produce an exception. But when using this compatibility class
+
+        input_hints & InputHints.PRIVATE
+
+    will just be False but not cause an exception.
+
+    See also:
+
+    https://docs.gtk.org/gtk3/flags.InputHints.html
+    https://docs.gtk.org/gtk4/flags.InputHints.html
+
+    Examples:
+
+    >>> int(InputHints.SPELLCHECK)
+    1
+
+    >>> InputHints.SPELLCHECK == 1
+    True
+
+    >>> InputHints.SPELLCHECK | 2
+    3
+
+    >>> 2 | InputHints.SPELLCHECK
+    3
+
+    >>> int(InputHints.NO_SPELLCHECK | InputHints.SPELLCHECK)
+    3
+
+    >>> 3 == InputHints.NO_SPELLCHECK | InputHints.SPELLCHECK
+    True
+
+    >>> 3 == InputHints.NO_SPELLCHECK | Gtk.InputHints.SPELLCHECK
+    True
+
+    >>> 3 == InputHints.NO_SPELLCHECK | IBus.InputHints.SPELLCHECK
+    True
+
+    >>> InputHints.SPELLCHECK == IBus.InputHints.SPELLCHECK
+    True
+
+    >>> InputHints.SPELLCHECK == Gtk.InputHints.SPELLCHECK
+    True
+    '''
+    def __new__(cls, attr: str) -> Any:
+        obj = object.__new__(cls)
+        if hasattr(Gtk, 'InputHints') and hasattr(Gtk.InputHints, attr):
+            obj._value_ = int(getattr(Gtk.InputHints, attr))
+        else:
+            obj._value_ = 0
+        return obj
+
+    def __int__(self) -> int:
+        return int(self._value_)
+
+    def __eq__(self, other: Any) -> bool:
+        if (self.__class__ is other.__class__
+            or other.__class__ is Gtk.InputHints
+            or other.__class__ is IBus.InputHints):
+            return bool(int(self) == int(other))
+        if other.__class__ is int or other.__class__ is float:
+            return bool(int(self) == other)
+        return NotImplemented
+
+    def __or__(self, other: Any) -> Any:
+        if self.__class__ is other.__class__:
+            return self.value | other.value
+        if (other.__class__ is Gtk.InputHints
+            or other.__class__ is IBus.InputHints):
+            return int(self) | int(other)
+        if other.__class__ is int:
+            return int(self) | other
+        return NotImplemented
+
+    def __ror__(self, other: Any) -> Any:
+        return self.__or__(other)
+
+    def __and__(self, other: Any) -> Any:
+        if self.__class__ is other.__class__:
+            return self.value & other.value
+        if (other.__class__ is Gtk.InputHints
+            or other.__class__ is IBus.InputHints):
+            return int(self) & int(other)
+        if other.__class__ is int:
+            return int(self) & other
+        return NotImplemented
+
+    def __rand__(self, other: Any) -> Any:
+        return self.__and__(other)
+
+    NONE = ('NONE')
+    SPELLCHECK = ('SPELLCHECK')
+    NO_SPELLCHECK = ('NO_SPELLCHECK')
+    WORD_COMPLETION = ('WORD_COMPLETION')
+    LOWERCASE = ('LOWERCASE')
+    UPPERCASE_CHARS = ('UPPERCASE_CHARS')
+    UPPERCASE_WORDS = ('UPPERCASE_WORDS')
+    UPPERCASE_SENTENCES = ('UPPERCASE_SENTENCES')
+    INHIBIT_OSK = ('INHIBIT_OSK')
+    VERTICAL_WRITING = ('VERTICAL_WRITING')
+    EMOJI = ('EMOJI')
+    NO_EMOJI = ('NO_EMOJI')
+    PRIVATE = ('PRIVATE')
+
 class KeyEvent:
     '''Key event class used to make the checking of details of the key
     event easy
@@ -389,24 +701,30 @@ class KeyEvent:
         return False
 
     def __str__(self) -> str:
-        return (
-            "val=%s code=%s state=0x%08x name='%s' unicode='%s' "
-            % (self.val,
-               self.code,
-               self.state,
-               self.name,
-               self.unicode)
-            + "shift=%s lock=%s control=%s super=%s hyper=%s meta=%s "
-            % (self.shift,
-               self.lock,
-               self.control,
-               self.super,
-               self.hyper,
-               self.meta)
-            + "mod1=%s mod5=%s release=%s\n"
-            % (self.mod1,
-               self.mod5,
-               self.release))
+        return repr(
+            f'val={self.val} '
+            f'code={self.code} '
+            f'state=0x{self.state:08x} '
+            f'name=“{self.name}” '
+            f'unicode=“{self.unicode}” '
+            f'shift={self.shift} '
+            f'lock={self.lock} '
+            f'control={self.control} '
+            f'super={self.super} '
+            f'hyper={self.hyper} '
+            f'meta={self.meta} '
+            f'mod1={self.mod1} '
+            f'mod2={self.mod2} '
+            f'mod3={self.mod3} '
+            f'mod4={self.mod4} '
+            f'mod5={self.mod5} '
+            f'button1={self.button1} '
+            f'button2={self.button2} '
+            f'button3={self.button3} '
+            f'button4={self.button4} '
+            f'button5={self.button5} '
+            f'release={self.release} '
+            f'modifier={self.modifier}')
 
 def keyevent_to_keybinding(keyevent: KeyEvent) -> str:
     keybinding = ''
